@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-nodeenv_version = '0.9.3'
+nodeenv_version = '0.9.4'
 
 import sys
 import os
@@ -34,6 +34,7 @@ abspath = os.path.abspath
 # ---------------------------------------------------------
 # Utils
 
+
 def clear_output(out):
     """
     Remove new-lines and
@@ -383,7 +384,7 @@ def get_node_src_url_postfix(opt):
     postfix_system = platform.system().lower()
     arches = {'x86_64': 'x64', 'i686': 'x86'}
     postfix_arch = arches[platform.machine()]
-    return '-{}-{}'.format(postfix_system, postfix_arch)
+    return '-{0}-{1}'.format(postfix_system, postfix_arch)
 
 # ---------------------------------------------------------
 # Virtual environment functions
@@ -411,7 +412,7 @@ def build_node_from_src(env_dir, src_dir, node_src_dir, opt):
         if value is not None
     ]
 
-    if sys.version_info.major > 2:
+    if getattr(sys.version_info, 'major', sys.version_info[0]) > 2:
         # Currently, the node.js build scripts are using python2.*,
         # therefore we need to temporarily point python exec to the
         # python 2.* version in this case.
@@ -557,7 +558,7 @@ def install_activate(env_dir, opt):
         # we should get `bin/node` not as binary+string.
         # `bin/activate` should be appended if we inside
         # existing python's virtual environment
-        need_append = False if name in ('node', 'shim') else opt.python_virtualenv
+        need_append = 0 if name in ('node', 'shim') else opt.python_virtualenv
         writefile(file_path, content, append=need_append)
         os.chmod(file_path, mode_0755)
 
